Index: third_party/WebKit/Source/core/dom/custom/CustomElement.h |
diff --git a/third_party/WebKit/Source/core/dom/custom/CustomElement.h b/third_party/WebKit/Source/core/dom/custom/CustomElement.h |
index 51c299f2853146d7c615e8d1cb386f932565bc0c..ec8f3c1546b5e74181b1b0e7f308088f848439f2 100644 |
--- a/third_party/WebKit/Source/core/dom/custom/CustomElement.h |
+++ b/third_party/WebKit/Source/core/dom/custom/CustomElement.h |
@@ -24,11 +24,11 @@ class CustomElementRegistry; |
class CORE_EXPORT CustomElement { |
STATIC_ONLY(CustomElement); |
public: |
// Retrieves the CustomElementsRegistry for Element, if any. This |
// may be a different object for a given element over its lifetime |
// as it moves between documents. |
- static CustomElementsRegistry* registry(const Element&); |
- static CustomElementsRegistry* registry(const Document&); |
+ static CustomElementRegistry* registry(const Element&); |
+ static CustomElementRegistry* registry(const Document&); |
static CustomElementDefinition* definitionForElement(const Element*); |
@@ -24,11 +24,11 @@ class CustomElementRegistry; |
STATIC_ONLY(CustomElement); |
public: |
- // Retrieves the CustomElementsRegistry for Element, if any. This |
+ // Retrieves the CustomElementRegistry for Element, if any. This |
// may be a different object for a given element over its lifetime |
// as it moves between documents. |